@@ -228,7 +228,9 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 			do {
 				pending_ack = FALSE;
 
-				timeout_ms = MAX (0, timeout_stop_ms - g_get_monotonic_time () / 1000);
+				timeout_ms = timeout_stop_ms - g_get_monotonic_time () / 1000;
+				if (timeout_ms < 0)
+					timeout_ms = 0;
 
 				success = TRUE;
 				success = success && g_poll (&io_data->poll_in_event, 1, timeout_ms) > 0;
@@ -568,7 +570,9 @@ arv_gv_device_auto_packet_size (ArvGvDevice *gv_device, GError **error)
 		return packet_size;
 	}
 
-	inc = MAX (1, arv_device_get_integer_feature_increment (device, "GevSCPSPacketSize", NULL));
+	inc = arv_device_get_integer_feature_increment (device, "GevSCPSPacketSize", NULL);
+	if (inc < 1)
+		inc = 1;
 	arv_device_get_integer_feature_bounds (device, "GevSCPSPacketSize", &minimum, &maximum, NULL);
 	max_size = MIN (65536, maximum);
 	min_size = MAX (ARV_GVSP_PACKET_PROTOCOL_OVERHEAD, minimum);
